@@ -248,7 +248,7 @@ class R3sponse(object):
 		
 		# check file size.
 		size = FilePath(self.log_file).size(mode="mb", type="integer")
-		if int(size.replace(" MB", "")) >= 100: self.reset_logs()
+		if size >= 100: self.reset_logs()
 
 		# return response.
 		return response
